@@ -9,8 +9,10 @@ import numpy as np
 from monty.serialization import dumpfn, loadfn
 from pymatgen.analysis.defects.generators import VoronoiInterstitialGenerator
 from pymatgen.analysis.defects.core import Interstitial as pmgInterstitial
-from pymatgen.core.structure import Structure
+from pymatgen.core.structure import Structure, Lattice
 from pymatgen.core.sites import PeriodicSite
+from pymatgen.core.tensors import Tensor
+from pymatgen.core.operations import SymmOp
 
 from apex.core.calculator.lib import abacus_utils
 from apex.core.calculator.lib import lammps_utils
@@ -23,6 +25,7 @@ from dflow.python import upload_packages
 upload_packages.append(__file__)
 
 PREDEFINED_LIST = ['bcc', 'fcc', 'hcp']
+TOL = 1e-5
 
 class Interstitial(Property):
     def __init__(self, parameter, inter_param=None):
@@ -33,7 +36,7 @@ class Interstitial(Property):
                 default_supercell = [1, 1, 1]
                 parameter["supercell"] = parameter.get("supercell", default_supercell)
                 self.supercell = parameter["supercell"]
-                self.insert_ele = parameter["insert_ele"]
+                self.insert_ele = parameter.get("insert_ele", None)
                 parameter["lattice_type"] = parameter.get("lattice_type", None)
                 self.lattice_type = parameter["lattice_type"]
                 parameter["voronoi_param"] = parameter.get("voronoi_param", {})
@@ -64,7 +67,7 @@ class Interstitial(Property):
     def make_confs(self, path_to_work, path_to_equi, refine=False):
         self.path_to_work = os.path.abspath(path_to_work)
         if os.path.exists(path_to_work):
-            logging.warning("%s already exists" % path_to_work)
+            logging.debug("%s already exists" % path_to_work)
         else:
             os.makedirs(path_to_work)
         path_to_equi = os.path.abspath(path_to_equi)
@@ -91,7 +94,7 @@ class Interstitial(Property):
         cwd = os.getcwd()
 
         if self.reprod:
-            logging.info("interstitial reproduce starts")
+            print("interstitial reproduce starts")
             if "init_data_path" not in self.parameter:
                 raise RuntimeError("please provide the initial data path to reproduce")
             init_data_path = os.path.abspath(self.parameter["init_data_path"])
@@ -105,7 +108,7 @@ class Interstitial(Property):
 
         else:
             if refine:
-                logging.info("interstitial refine starts")
+                print("interstitial refine starts")
                 self.task_list = make_refine(
                     self.parameter["init_from_suffix"],
                     self.parameter["output_suffix"],
@@ -157,7 +160,9 @@ class Interstitial(Property):
                     ss = abacus_utils.stru2Structure(equi_contcar)
                 else:
                     ss = Structure.from_file(equi_contcar)
-
+                rot = Tensor.get_ieee_rotation(ss)
+                op = SymmOp.from_rotation_and_translation(rot)
+                ss.apply_operation(op)
                 # get structure type
                 os.chdir(self.path_to_work)
                 # convert site element into same type for a pseudo-structure just for simple lattice type judgment
@@ -171,9 +176,10 @@ class Interstitial(Property):
                 orig_st = StructureInfo(ss, symprec=0.1, angle_tolerance=5)
                 conv_ss = orig_st.conventional_structure
                 conv_ss.to("POSCAR", "POSCAR")
+                conv_ss.to("POSCAR_conv", "POSCAR")
                 ss = conv_ss
                 if self.lattice_type:
-                    logging.info(msg=f'Adopt user indicated lattice type: {self.lattice_type}')
+                    print(f'Adopt user indicated lattice type: {self.lattice_type}')
                     self.structure_type = self.lattice_type
                 os.chdir(cwd)
 
@@ -182,8 +188,31 @@ class Interstitial(Property):
                 self.insert_element_task = os.path.join(self.path_to_work, "element.out")
                 if os.path.isfile(self.insert_element_task):
                     os.remove(self.insert_element_task)
+                if not self.insert_ele:
+                    self.insert_ele = [str(ii) for ii in set(ss.composition.elements)]
                 for ii in self.insert_ele:
                     if self.structure_type in PREDEFINED_LIST:
+                        # rotate and translate hcp structure to specific orientation for interstitial generation
+                        if self.structure_type == 'hcp':
+                            theta = -2 * np.pi / 3
+                            rot_m = np.array([
+                                [np.cos(theta), -np.sin(theta), 0],
+                                [np.sin(theta), np.cos(theta), 0],
+                                [0, 0, 1]
+                            ])
+                            op = SymmOp.from_rotation_and_translation(rotation_matrix=rot_m)
+                            ss.apply_operation(op)
+                            new_lattice = Lattice([
+                                ss.lattice.matrix[0] * -1, ss.lattice.matrix[1] * -1, ss.lattice.matrix[2]
+                            ])
+                            new_frac_coords = ss.frac_coords.copy()
+                            if not ((new_frac_coords[0][0] < 0.5 and new_frac_coords[0][2] < 0.5)\
+                                    or (new_frac_coords[0][0] > 0.5 and new_frac_coords[0][2] > 0.5)):
+                                new_frac_coords[0][2] = ss.frac_coords[1][2]
+                                new_frac_coords[1][2] = ss.frac_coords[0][2]
+                            new_ss = Structure(new_lattice, ss.species, new_frac_coords, coords_are_cartesian=False)
+                            ss = new_ss
+                            ss.to(os.path.join(self.path_to_work, 'POSCAR_conv'), 'POSCAR')
                         # produce a pseudo interstitial structure for later modification
                         vds = [pmgInterstitial(ss, PeriodicSite(ii, [0.12, 0.13, 0.14], ss.lattice))]
                     else:
@@ -210,7 +239,7 @@ class Interstitial(Property):
                         #            dss.append(jj.generate_defect_structure(self.supercell))
                         self.dss = dss
 
-                logging.info(
+                print(
                     "gen interstitial with supercell "
                     + str(self.supercell)
                     + " with element "
@@ -250,10 +279,11 @@ class Interstitial(Property):
 
                 # create pre-defined special SIA structure for bcc fcc and hcp
                 if self.structure_type in PREDEFINED_LIST:
+                    self.task_list = []
                     if not os.path.isfile("task.000000/POSCAR"):
                         raise RuntimeError("need task.000000 structure as reference")
 
-                    with open('POSCAR', "r") as fin:
+                    with open('POSCAR_conv', "r") as fin:
                         fin.readline()
                         scale = float(fin.readline().split()[0])
                         self.latt_param = float(fin.readline().split()[0])
@@ -266,13 +296,12 @@ class Interstitial(Property):
                         ss = ii.split()
                         if len(ss) > 3:
                             if (
-                                    abs(0.12 / self.supercell[0] - float(ss[0])) < 1e-5
-                                    and abs(0.13 / self.supercell[1] - float(ss[1])) < 1e-5
-                                    and abs(0.14 / self.supercell[2] - float(ss[2])) < 1e-5
+                                    abs(0.12 / self.supercell[0] - float(ss[0])) < TOL
+                                    and abs(0.13 / self.supercell[1] - float(ss[1])) < TOL
+                                    and abs(0.14 / self.supercell[2] - float(ss[2])) < TOL
                             ):
                                 chl = idx
-                    # pseudo-task only run original POSCAR to save calculation resources
-                    shutil.copyfile("POSCAR", "task.000000/POSCAR")
+                    shutil.rmtree("task.000000")
 
                     os.chdir(cwd)
                     # specify interstitial structures
@@ -281,15 +310,15 @@ class Interstitial(Property):
                             ss = ii.split()
                             if len(ss) > 3:
                                 if (
-                                        abs(0.5 / self.supercell[0] - float(ss[0])) < 1e-5
-                                        and abs(0.5 / self.supercell[1] - float(ss[1])) < 1e-5
-                                        and abs(0.5 / self.supercell[2] - float(ss[2])) < 1e-5
+                                        abs(0.5 / self.supercell[0] - float(ss[0])) < TOL
+                                        and abs(0.5 / self.supercell[1] - float(ss[1])) < TOL
+                                        and abs(0.5 / self.supercell[2] - float(ss[2])) < TOL
                                 ):
                                     center = idx
                         bcc_interstital_dict = {
                             'tetrahedral': {chl: [0.25, 0.5, 0]},
                             'octahedral': {chl: [0.5, 0.5, 0]},
-                            'crowdion': {chl: [0.25, 0.25, 0]},
+                            'crowdion': {chl: [0.25, 0.25, 0.25]},
                             '<111>dumbbell': {chl: [1 / 3, 1 / 3, 1 / 3],
                                               center: [2 / 3, 2 / 3, 2 / 3]},
                             '<110>dumbbell': {chl: [1 / 4, 3 / 4, 1 / 2],
@@ -304,16 +333,16 @@ class Interstitial(Property):
                             ss = ii.split()
                             if len(ss) > 3:
                                 if (
-                                        abs(1 / self.supercell[0] - float(ss[0])) < 1e-5
-                                        and abs(0.5 / self.supercell[1] - float(ss[1])) < 1e-5
-                                        and abs(0.5 / self.supercell[2] - float(ss[2])) < 1e-5
+                                        abs(1 / self.supercell[0] - float(ss[0])) < TOL
+                                        and abs(0.5 / self.supercell[1] - float(ss[1])) < TOL
+                                        and abs(0.5 / self.supercell[2] - float(ss[2])) < TOL
                                 ):
                                     face = idx
 
                                 if (
-                                        abs(1 / self.supercell[0] - float(ss[0])) < 1e-5
-                                        and abs(1 / self.supercell[1] - float(ss[1])) < 1e-5
-                                        and abs(1 / self.supercell[2] - float(ss[2])) < 1e-5
+                                        abs(1 / self.supercell[0] - float(ss[0])) < TOL
+                                        and abs(1 / self.supercell[1] - float(ss[1])) < TOL
+                                        and abs(1 / self.supercell[2] - float(ss[2])) < TOL
                                 ):
                                     corner = idx
 
@@ -349,9 +378,9 @@ class Interstitial(Property):
                             ss = ii.split()
                             if len(ss) > 3:
                                 if (
-                                        abs(1/3 / self.supercell[0] - float(ss[0])) < 1e-5
-                                        and abs(2/3 / self.supercell[1] - float(ss[1])) < 1e-5
-                                        and abs(0.25 / self.supercell[2] - float(ss[2])) < 1e-5
+                                        abs(1/3 / self.supercell[0] - float(ss[0])) < TOL
+                                        and abs(2/3 / self.supercell[1] - float(ss[1])) < TOL
+                                        and abs(0.25 / self.supercell[2] - float(ss[2])) < TOL
                                 ):
                                     center = idx
                         hcp_interstital_dict = {
@@ -379,7 +408,7 @@ class Interstitial(Property):
                         output_task = os.path.join(self.path_to_work, "task.%06d" % ii)
                         os.chdir(output_task)
                         abacus_utils.poscar2stru("POSCAR", self.inter_param, "STRU")
-                        os.remove("POSCAR")
+                        #os.remove("POSCAR")
         os.chdir(cwd)
         return self.task_list
 
@@ -387,7 +416,7 @@ class Interstitial(Property):
         cwd = os.getcwd()
         for ii, (type_str, adjust_dict) in enumerate(interstitial_dict.items()):
             output_task = os.path.join(
-                self.path_to_work, "task.%06d" % (len(self.dss) + ii)
+                self.path_to_work, "task.%06d" % (len(self.dss) + ii - 1)
             )
             os.makedirs(output_task, exist_ok=True)
             os.chdir(output_task)
@@ -411,13 +440,14 @@ class Interstitial(Property):
             with open("POSCAR", "w+") as fout:
                 for ii in new_pos_line:
                     print(ii, file=fout)
-            logging.info(f"gen {type_str}")
+            print(f"gen {type_str}")
             os.chdir(cwd)
 
-        total_task = len(self.dss) + len(interstitial_dict)
+        total_task = len(self.dss) + len(interstitial_dict) - 1
 
         return total_task
 
+
     def post_process(self, task_list):
         if True:
             fin1 = open(os.path.join(task_list[0], "..", "element.out"), "r")
@@ -472,7 +502,7 @@ class Interstitial(Property):
             equi_result = loadfn(os.path.join(equi_path, "result.json"))
             equi_epa = equi_result["energies"][-1] / sum(equi_result["atom_numbs"])
 
-            for idid, ii in enumerate(all_tasks[1:], start=1): # skip task.000000
+            for idid, ii in enumerate(all_tasks, start=0): # skip task.000000
                 structure_dir = os.path.basename(ii)
                 task_result = loadfn(all_res[idid])
                 interstitial_type = loadfn(os.path.join(ii, 'interstitial_type.json'))
